@@ -42,7 +42,8 @@
 #include "packages.h"
 #include "interface.h"
 #include "main.h"
-#include "filesel.h"
+//#include "filesel.h"
+#include "filechooser.h"
 
 #define N_(x) (x)
 
@@ -118,7 +119,7 @@ void on_package_info_clicked(GtkButton *button, gpointer user_data);
 
 static GtkItemFactoryEntry mMain_items[] = {
   { N_("/_File"),         NULL,         NULL, MI_FILE, "<Branch>" },
-  { N_("/File/_Install file"), "", on_select_local, MI_FILE_INSTALL, "<Item>"},
+  { N_("/File/_Install file"), "", on_select_local, MI_FILE_INSTALL, "<StockItem>", GTK_STOCK_OPEN},
   { N_("/_File/s1"), NULL , NULL,    0, "<Separator>"},
   { N_("/File/_Close"),  NULL, do_safe_exit, MI_FILE_CLOSE, "<StockItem>", GTK_STOCK_QUIT },
   { N_("/_Packages"),         NULL,         NULL, MI_PACKAGES, "<Branch>" },
@@ -133,7 +134,7 @@ static GtkItemFactoryEntry mMain_items[] = {
   { N_("/Packages/_Apply"), "", on_package_install_clicked, MI_PACKAGES_APPLY, "<StockItem>", GTK_STOCK_APPLY},
   { N_("/_Help"),         NULL,         NULL,           0, "<Branch>" },
   { N_("/_Help/Index"),   NULL,         on_help_clicked,    0, "<StockItem>",GTK_STOCK_HELP },
-  { N_("/_Help/About"),   NULL,         on_about_clicked,    0, "<Item>" },
+  { N_("/_Help/About"),   NULL,         on_about_clicked,    0, "<Item>" }
 };
 
 int mMain_items_count = sizeof(mMain_items) / sizeof(GtkItemFactoryEntry);
@@ -142,7 +143,8 @@ int mMain_items_count = sizeof(mMain_items) / sizeof(GtkItemFactoryEntry);
 struct gpe_icon my_icons[] = {
   { "exit" },
   { "local-package", PREFIX "/share/pixmaps/local-package-16.png" },
-  { "icon", PREFIX "/share/pixmaps/gpe-package.png" }
+  { "icon", PREFIX "/share/pixmaps/gpe-package.png" },
+  { NULL, NULL}
 };
 
 
@@ -728,7 +730,8 @@ int do_package_check(const char *package)
 
 void on_select_local(GtkButton *button, gpointer user_data)
 {
-	ask_user_a_file("/tmp",_("Select package file"),do_local_install,NULL,NULL);
+	//ask_user_a_file("/tmp",_("Select package file"),do_local_install,NULL,NULL);
+	package_choose(fMain, do_local_install);
 }
 
 
