@@ -12,8 +12,6 @@
  *
  */
 
-#define _GNU_SOURCE
-
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/socket.h>
@@ -77,8 +75,8 @@ main (int argc, char *argv[])
 		{
 			suidloop(csock);
 			close(csock);
+			close(lsock);
 		}
-		kill(suidPID,SIGTERM);
 	}
 	else
 	{
@@ -89,7 +87,6 @@ main (int argc, char *argv[])
 		signal(SIGTERM, do_safe_exit);
 		signal(SIGINT, do_safe_exit);
 		mainloop(argc, argv);	
-
 	}
 	
 	unlink(PK_SOCKET);
